# import sys
# sys.path.append(r'D:/Projects/Python/easydsi')

from easydsi.linked_list import *
from easydsi.array import *
from easydsi.stack import *
from easydsi.queue import *
from easydsi.tree import *

__version__ = "1.1.1"
__developer__ = "Mohamed Fazil Z"
__website__ = "https://github.com/fazil2003/easydsi"