class Node():
    pass

class Tree():
    
    def __init__(self):
        pass

def binary_tree():
    return Tree()

def binary_search_tree():
    return

def max_heap():
    return

def min_heap():
    return